@@ -34,17 +34,14 @@ readColumns <- function(sheet, startColumn, endColumn, startRow,
   }
 
   # guess or expand colClasses
-  if (length(colClasses) < noColumns) {
-    colClasses <-rep(colClasses, noColumns)   
-  } else if (length(colClasses)==1 && (is.na(colClasses))) {
+  if (is.na(colClasses)[1]) {
     row <- getRows(sheet, rowIndex=startRow) 
     cells <- getCells(row, colIndex=startColumn:endColumn)
-    if (length(cells) == noColumns) {
-      .guess_cell_type(cells)
-    } else {
-      warning("Cannot guess colClasses from the first row of data!")
-    }
+    if (length(cells) != noColumns) 
+      warning("Not enough columns in the first row of data to correctly guess colClasses!")
+    colClasses <- .guess_cell_type(cells)
   }
+  colClasses <- rep(colClasses, length.out=noColumns)  # extend colClasses
   
   res <- vector("list", length=noColumns)
   for (i in seq_len(noColumns)) {
@@ -63,7 +60,7 @@ readColumns <- function(sheet, startColumn, endColumn, startRow,
         as.integer(startRow-1), as.integer(endRow-1), 
         as.integer(startColumn-1+i-1))
     }
-
+#browser()
     if (!is.na(colClasses[i]))
       suppressWarnings(class(aux) <- colClasses[i])  # if it gets specified
     res[[i]] <- aux
